@@ -136,7 +136,7 @@
     <message>
         <location filename="mainwindow.ui" line="372"/>
         <source>Don&apos;t use fuseiso to mount iso files</source>
-        <translation type="unfinished"/>
+        <translation>Não usar fuseiso para montar ficheiros iso</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="398"/>
@@ -151,12 +151,12 @@
     <message>
         <location filename="mainwindow.ui" line="457"/>
         <source>vfat</source>
-        <translation type="unfinished"/>
+        <translation>vfat</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="462"/>
         <source>exfat</source>
-        <translation type="unfinished"/>
+        <translation>exfat</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="467"/>
@@ -166,12 +166,12 @@
     <message>
         <location filename="mainwindow.ui" line="472"/>
         <source>ntfs</source>
-        <translation type="unfinished"/>
+        <translation>ntfs</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="493"/>
         <source>Make separate data partition (percent)</source>
-        <translation type="unfinished"/>
+        <translation>Criar partição de dados separada (percentagem)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="500"/>
@@ -319,7 +319,7 @@ Aguardar até o processo terminar</translation>
     <message>
         <location filename="mainwindow.cpp" line="355"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>Sobre o %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="356"/>
@@ -339,12 +339,12 @@ Aguardar até o processo terminar</translation>
     <message>
         <location filename="mainwindow.cpp" line="360"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>Licença do %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="368"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>Ajuda do %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="379"/>
